Prepare 'RAVE' single-subject data
prepare_subject_bare0(
subject,
electrodes,
reference_name,
...,
quiet = TRUE,
repository_id = NULL
)prepare_subject_bare(
subject,
electrodes,
reference_name,
...,
repository_id = NULL
)
prepare_subject_with_epoch(
subject,
electrodes,
reference_name,
epoch_name,
time_windows,
env = parent.frame(),
...
)
prepare_subject_with_blocks(
subject,
electrodes,
reference_name,
blocks,
signal_type = "LFP",
time_frequency = signal_type == "LFP",
env = parent.frame(),
repository_id = NULL,
...
)
prepare_subject_phase(
subject,
electrodes,
reference_name,
epoch_name,
time_windows,
signal_type = c("LFP"),
env = parent.frame(),
verbose = TRUE,
...
)
prepare_subject_power(
subject,
electrodes,
reference_name,
epoch_name,
time_windows,
signal_type = c("LFP"),
env = parent.frame(),
verbose = TRUE,
...
)
prepare_subject_wavelet(
subject,
electrodes,
reference_name,
epoch_name,
time_windows,
signal_type = c("LFP"),
env = parent.frame(),
verbose = TRUE,
...
)
prepare_subject_raw_voltage_with_epoch(
subject,
electrodes,
epoch_name,
time_windows,
...,
quiet = TRUE,
repository_id = NULL
)
prepare_subject_voltage_with_epoch(
subject,
electrodes,
epoch_name,
time_windows,
reference_name,
...,
quiet = TRUE,
repository_id = NULL
)
A fastmap2 (basically a list) of objects.
Depending on the functions called, the following items may exist in the list:
subjectA RAVESubject instance
epoch_nameSame as input epoch_name
epochA RAVEEpoch instance
reference_nameSame as input reference_name
reference_tableA data frame of reference
electrode_tableA data frame of electrode information
frequencyA vector of frequencies
time_pointsA vector of time-points
power_listA list of power data of the electrodes
power_dimnamesA list of trial indices, frequencies, time points, and electrodes that are loaded
character of project and subject, such as "demo/YAB",
or RAVESubject instance
integer vector of electrodes, or a character that can be
parsed by parse_svec
reference name to be loaded
ignored
whether to quietly load the data
used internally
epoch name to be loaded, or a
RAVEEpoch instance
a list of time windows that are relative to epoch onset
time; need to pass the validation validate_time_window
environment to evaluate
one or more session blocks to load
electrode signal type (length of one) to be considered;
default is 'LFP'. This option rarely needs to change unless you really want
to check the power data from other types. For other signal types, check
SIGNAL_TYPES
whether to load time-frequency data when preparing block data
whether to show progress