Persist settings on local configuration file
raveio_setopt(key, value, .save = TRUE)raveio_resetopt(all = FALSE)
raveio_getopt(key, default = NA, temp = TRUE)
raveio_confpath(cfile = "settings.yaml")
raveio_setopt returns modified value;
raveio_resetopt returns current settings as a list;
raveio_confpath returns absolute path for the settings file;
raveio_getopt returns the settings value to the given key, or
default if not found.
character, option name
character or logical of length 1, option value
whether to save to local drive, internally used to temporary change option. Not recommended to use it directly.
whether to reset all non-default keys
is key not found, return default value
when saving, whether the key-value pair should be considered
temporary, a temporary settings will be ignored when saving; when getting
options, setting temp to false will reveal the actual settings.
file name in configuration path
raveio_setopt stores key-value pair in local path.
The values are persistent and shared across multiple sessions.
There are some read-only keys such as "session_string". Trying to
set those keys will result in error.
raveio_getopt returns value corresponding to the keys. If key is
missing, the whole option will be returned.
If set all=TRUE, raveio_resetopt resets all keys including
non-standard ones. However "session_string" will never reset.
R_user_dir